@@ -1,5 +1,5 @@
 from io import BytesIO
-from typing import List, Union
+from typing import List
 
 from .download import download_url, download_avatar
 from .utils import to_image
@@ -7,6 +7,8 @@ from .models import UserInfo, Command
 from .functions import *
 
 commands = [
+    Command(("图片操作",), operations, allow_gif=True, arg_num=2),
+    Command(("万能表情",), universal, allow_gif=True, arg_num=10),
     Command(("摸", "摸摸", "摸头", "摸摸头", "rua"), petpet, arg_num=1),
     Command(("亲", "亲亲"), kiss),
     Command(("贴", "贴贴", "蹭", "蹭蹭"), rub),
@@ -17,41 +19,41 @@ commands = [
     Command(("抛", "掷"), throw_gif),
     Command(("爬",), crawl, arg_num=1),
     Command(("精神支柱",), support),
-    Command(("一直",), always, convert=False),
-    Command(("加载中",), loading, convert=False),
+    Command(("一直",), always, allow_gif=True),
+    Command(("加载中",), loading, allow_gif=True),
     Command(("转",), turn),
-    Command(("小天使",), littleangel, convert=False, arg_num=1),
+    Command(("小天使",), littleangel, arg_num=1),
     Command(("不要靠近",), dont_touch),
     Command(("一样",), alike),
     Command(("滚",), roll),
-    Command(("玩游戏", "来玩游戏"), play_game, convert=False, arg_num=1),
+    Command(("玩游戏", "来玩游戏"), play_game, allow_gif=True, arg_num=1),
     Command(("膜", "膜拜"), worship),
     Command(("吃",), eat),
     Command(("啃",), bite),
     Command(("出警",), police),
-    Command(("警察",), police1, convert=False),
-    Command(("问问", "去问问"), ask, convert=False, arg_num=1),
-    Command(("舔", "舔屏", "prpr"), prpr, convert=False),
+    Command(("警察",), police1),
+    Command(("问问", "去问问"), ask, arg_num=1),
+    Command(("舔", "舔屏", "prpr"), prpr, allow_gif=True),
     Command(("搓",), twist),
-    Command(("墙纸",), wallpaper, convert=False),
+    Command(("墙纸",), wallpaper, allow_gif=True),
     Command(("国旗",), china_flag),
-    Command(("交个朋友",), make_friend, convert=False, arg_num=1),
-    Command(("继续干活",), back_to_work, convert=False),
-    Command(("完美", "完美的"), perfect, convert=False),
+    Command(("交个朋友",), make_friend, arg_num=1),
+    Command(("继续干活", "打工人"), back_to_work),
+    Command(("完美", "完美的"), perfect),
     Command(("关注",), follow, arg_num=1),
     Command(("我朋友说", "我有个朋友说"), my_friend, arg_num=10),
-    Command(("这像画吗",), paint, convert=False),
+    Command(("这像画吗",), paint),
     Command(("震惊",), shock),
     Command(("兑换券",), coupon, arg_num=2),
     Command(("听音乐",), listen_music),
-    Command(("典中典",), dianzhongdian, convert=False, arg_num=3),
+    Command(("典中典",), dianzhongdian, arg_num=3),
     Command(("哈哈镜",), funny_mirror),
     Command(("永远爱你",), love_you),
-    Command(("对称",), symmetric, convert=False, arg_num=1),
-    Command(("安全感",), safe_sense, convert=False, arg_num=2),
-    Command(("永远喜欢", "我永远喜欢"), always_like, convert=False, arg_num=10),
+    Command(("对称",), symmetric, arg_num=1),
+    Command(("安全感",), safe_sense, arg_num=2),
+    Command(("永远喜欢", "我永远喜欢"), always_like, arg_num=10),
     Command(("采访",), interview, arg_num=1),
-    Command(("打拳",), punch, convert=False),
+    Command(("打拳",), punch),
     Command(("群青",), cyan),
     Command(("捣",), pound),
     Command(("捶",), thump),
@@ -60,15 +62,17 @@ commands = [
     Command(("敲",), knock),
     Command(("垃圾", "垃圾桶"), garbage),
     Command(("为什么@我", "为什么at我"), whyatme),
-    Command(("像样的亲亲",), decent_kiss, convert=False),
-    Command(("啾啾",), jiujiu, convert=False),
+    Command(("像样的亲亲",), decent_kiss),
+    Command(("啾啾",), jiujiu),
     Command(("吸", "嗦"), suck),
     Command(("锤",), hammer),
-    Command(("紧贴", "紧紧贴着"), tightly, convert=False),
+    Command(("紧贴", "紧紧贴着"), tightly),
+    Command(("注意力涣散",), distracted),
+    Command(("阿尼亚喜欢",), anyasuki, arg_num=1),
 ]
 
 
-async def download_image(user: UserInfo, convert: bool = True):
+async def download_image(user: UserInfo, allow_gif: bool = False):
     img = None
     if user.qq:
         img = await download_avatar(user.qq)
@@ -76,13 +80,13 @@ async def download_image(user: UserInfo, convert: bool = True):
         img = await download_url(user.img_url)
 
     if img:
-        user.img = to_image(img, convert)
+        user.img = to_image(img, allow_gif)
 
 
 async def make_image(
     command: Command, sender: UserInfo, users: List[UserInfo], args: List[str] = []
-) -> Union[str, BytesIO]:
-    await download_image(sender, command.convert)
+) -> BytesIO:
+    await download_image(sender, command.allow_gif)
     for user in users:
-        await download_image(user, command.convert)
+        await download_image(user, command.allow_gif)
     return await command.func(users, sender=sender, args=args)
