@@ -1,15 +1,103 @@
 import random
 from io import BytesIO
-from typing import Union, List
+from typing import List
 from PIL.Image import Image as IMG
-from PIL import Image, ImageFilter, ImageDraw
+from PIL import Image, ImageFilter, ImageDraw, ImageOps
 
 from .models import UserInfo
 from .utils import *
 
 
-async def petpet(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
+TEXT_TOO_LONG = "文字太长了哦，改短点再试吧~"
+NAME_TOO_LONG = "名字太长了哦，改短点再试吧~"
+REQUIRE_NAME = "找不到名字，加上名字再试吧~"
+REQUIRE_ARG = "该表情至少需要一个参数"
+
+
+async def operations(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
+    help_msg = "支持的操作：水平翻转、垂直翻转、黑白、旋转、反相、浮雕、轮廓、锐化"
+    if not args:
+        raise ValueError(help_msg)
+
+    op = args[0]
+    if op == "倒放" and getattr(img, "is_animated", False):
+        duration = img.info["duration"] / 1000
+        frames = []
+        for i in range(img.n_frames):
+            img.seek(i)
+            frames.append(img.convert("RGB"))
+        frames.reverse()
+        return save_gif(frames, duration)
+
+    async def make(img: IMG) -> IMG:
+        if op == "水平翻转":
+            frame = img.transpose(Image.FLIP_LEFT_RIGHT)
+        elif op == "垂直翻转":
+            frame = img.transpose(Image.FLIP_TOP_BOTTOM)
+        elif op == "黑白":
+            frame = img.convert("L")
+        elif op == "旋转":
+            angle = int(args[1]) if args[1:] and args[1].isdigit() else 90
+            frame = rotate(img, int(angle))
+        elif op == "反相":
+            frame = ImageOps.invert(img)
+        elif op == "浮雕":
+            frame = img.filter(ImageFilter.EMBOSS)
+        elif op == "轮廓":
+            frame = img.filter(ImageFilter.CONTOUR)
+        elif op == "锐化":
+            frame = img.filter(ImageFilter.SHARPEN)
+        else:
+            raise ValueError(help_msg)
+        return frame
+
+    return await make_jpg_or_gif(img, make)
+
+
+async def universal(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
+    img = users[0].img
+    if not args:
+        args = ["万能表情"]
+
+    img_w, img_h = limit_size(img, (500, 500), FitSizeMode.INSIDE).size
+    fontname = DEFAULT_FONT
+    min_fontsize = 50
+    for a in args:
+        fontsize = await fit_font_size(a, img_w - 20, img_h, fontname, 50, 10)
+        if not fontsize:
+            raise ValueError(TEXT_TOO_LONG)
+        if fontsize < min_fontsize:
+            min_fontsize = fontsize
+
+    async def make(img: IMG) -> IMG:
+        img = limit_size(img, (500, 500), FitSizeMode.INSIDE)
+        frames: List[IMG] = [img]
+
+        async def text_frame(text: str, fontsize: int):
+            font = await load_font(fontname, fontsize)
+            text_w, text_h = font.getsize(text)
+            frame = Image.new("RGB", (img_w, text_h + 5), "white")
+            await draw_text(
+                frame, ((img_w - text_w) / 2, 0), text, font=font, fill="black"
+            )
+            frames.append(frame)
+
+        for a in args:
+            await text_frame(a, min_fontsize)
+
+        frame = Image.new("RGB", (img_w, sum((f.height for f in frames)) + 10), "white")
+        current_h = 0
+        for f in frames:
+            frame.paste(f, (0, current_h))
+            current_h += f.height
+        return frame
+
+    return await make_jpg_or_gif(img, make)
+
+
+async def petpet(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
+    img = square(users[0].img)
     frames = []
     locs = [
         (14, 20, 98, 98),
@@ -38,6 +126,8 @@ async def kiss(users: List[UserInfo], sender: UserInfo, **kwargs) -> BytesIO:
     else:
         self_img = sender.img
         user_img = users[0].img
+    self_head = resize(circle(self_img), (40, 40))
+    user_head = resize(circle(user_img), (50, 50))
     # fmt: off
     user_locs = [
         (58, 90), (62, 95), (42, 100), (50, 100), (56, 100), (18, 120), (28, 110),
@@ -51,9 +141,7 @@ async def kiss(users: List[UserInfo], sender: UserInfo, **kwargs) -> BytesIO:
     frames = []
     for i in range(13):
         frame = await load_image(f"kiss/{i}.png")
-        user_head = resize(circle(user_img), (50, 50))
         frame.paste(user_head, user_locs[i], mask=user_head)
-        self_head = resize(circle(self_img), (40, 40))
         frame.paste(self_head, self_locs[i], mask=self_head)
         frames.append(frame)
     return save_gif(frames, 0.05)
@@ -90,7 +178,7 @@ async def rub(users: List[UserInfo], sender: UserInfo, **kwargs) -> BytesIO:
 
 
 async def play(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     # fmt: off
     locs = [
         (180, 60, 100, 100), (184, 75, 100, 100), (183, 98, 100, 100),
@@ -123,7 +211,7 @@ async def play(users: List[UserInfo], **kwargs) -> BytesIO:
 
 
 async def pat(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     locs = [(11, 73, 106, 100), (8, 79, 112, 96)]
     img_frames = []
     for i in range(10):
@@ -142,7 +230,7 @@ async def pat(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def rip(
     users: List[UserInfo], sender: UserInfo, args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+) -> BytesIO:
     if len(users) >= 2:
         self_img = users[0].img
         user_img = users[1].img
@@ -158,18 +246,18 @@ async def rip(
     text = arg.strip("滑稽").strip()
 
     frame = Image.new("RGBA", rip.size, (255, 255, 255, 0))
-    left = rotate(resize(user_img, (385, 385)), 24)
-    right = rotate(resize(user_img, (385, 385)), -11)
+    left = rotate(fit_size(user_img, (385, 385)), 24)
+    right = rotate(fit_size(user_img, (385, 385)), -11)
     frame.paste(left, (-5, 355))
     frame.paste(right, (649, 310))
-    frame.paste(resize(self_img, (230, 230)), (408, 418))
+    frame.paste(fit_size(self_img, (230, 230)), (408, 418))
     frame.paste(rip, mask=rip)
 
     if text:
         fontname = BOLD_FONT
         fontsize = await fit_font_size(text, rip.width - 50, 300, fontname, 150, 25)
         if not fontsize:
-            return "文字太长了哦，改短点再试吧~"
+            raise ValueError(TEXT_TOO_LONG)
         font = await load_font(fontname, fontsize)
         text_w = font.getsize(text)[0]
         await draw_text(
@@ -228,7 +316,7 @@ async def support(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     support = await load_image("support/0.png")
     frame = Image.new("RGBA", support.size, (255, 255, 255, 0))
-    img = rotate(resize(img, (815, 815)), 23)
+    img = rotate(fit_size(img, (815, 815)), 23)
     frame.paste(img, (-172, -17))
     frame.paste(support, mask=support)
     return save_jpg(frame)
@@ -243,7 +331,6 @@ async def always(users: List[UserInfo], **kwargs) -> BytesIO:
     height = h1 + h2 + 10
 
     async def make(img: IMG) -> IMG:
-        img = to_jpg(img)
         frame = Image.new("RGBA", (300, height), (255, 255, 255, 0))
         frame.paste(always, (0, h1 - 300 + int((h2 - 60) / 2)))
         frame.paste(resize(img, (300, h1)), (0, 0))
@@ -263,7 +350,7 @@ async def loading(users: List[UserInfo], **kwargs) -> BytesIO:
     height = h1 + h2 + 10
 
     def make_static(img: IMG) -> IMG:
-        img = to_jpg(img)
+        img = to_jpg(img).convert("RGBA")
         frame = Image.new("RGBA", (300, height), (255, 255, 255, 0))
         frame.paste(bg, (0, h1 - 300 + int((h2 - 60) / 2)))
         img = resize(img, (300, h1))
@@ -297,11 +384,8 @@ async def turn(users: List[UserInfo], **kwargs) -> BytesIO:
     return save_gif(frames, 0.05)
 
 
-async def littleangel(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def littleangel(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     img = limit_size(img, (500, 500), FitSizeMode.INSIDE)
     img_w, img_h = img.size
 
@@ -328,7 +412,7 @@ async def littleangel(
     text = f"请问你们看到{name}了吗?"
     fontsize = await fit_font_size(text, 560, 110, fontname, 70, 25)
     if not fontsize:
-        return "名字太长了哦，改短点再试吧~"
+        raise ValueError(NAME_TOO_LONG)
 
     font = await load_font(fontname, fontsize)
     text_w, text_h = font.getsize(text)
@@ -341,19 +425,20 @@ async def littleangel(
 async def dont_touch(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     frame = await load_image("dont_touch/0.png")
-    frame.paste(resize(img, (170, 170)), (23, 231))
+    frame.paste(fit_size(img, (170, 170)), (23, 231))
     return save_jpg(frame)
 
 
 async def alike(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     frame = await load_image("alike/0.png")
-    frame.paste(resize(img, (90, 90)), (131, 14))
+    frame.paste(fit_size(img, (90, 90)), (131, 14))
     return save_jpg(frame)
 
 
 async def roll(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
+    img = fit_size(img, (210, 210))
     frames = []
     # fmt: off
     locs = [
@@ -364,28 +449,25 @@ async def roll(users: List[UserInfo], **kwargs) -> BytesIO:
     for i in range(8):
         frame = Image.new("RGBA", (300, 300), (255, 255, 255, 0))
         x, y, a = locs[i]
-        frame.paste(rotate(resize(img, (210, 210)), a, expand=False), (x, y))
+        frame.paste(rotate(img, a, expand=False), (x, y))
         bg = await load_image(f"roll/{i}.png")
         frame.paste(bg, mask=bg)
         frames.append(frame)
     return save_gif(frames, 0.1)
 
 
-async def play_game(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def play_game(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
     bg = await load_image("play_game/1.png")
     text = args[0] if args else "来玩休闲游戏啊"
     fontname = DEFAULT_FONT
     fontsize = await fit_font_size(text, 520, 110, fontname, 35, 25)
     if not fontsize:
-        return "描述太长了哦，改短点再试吧~"
+        raise ValueError(TEXT_TOO_LONG)
     font = await load_font(fontname, fontsize)
     text_w = font.getsize(text)[0]
 
     async def make(img: IMG) -> IMG:
-        img = to_jpg(img)
         frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
         points = [(0, 5), (227, 0), (216, 150), (0, 165)]
         screen = rotate(perspective(fit_size(img, (220, 160)), points), 9)
@@ -409,7 +491,7 @@ async def play_game(
 async def worship(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     points = [(0, -30), (135, 17), (135, 145), (0, 140)]
-    paint = perspective(resize(img, (150, 150)), points)
+    paint = perspective(fit_size(img, (150, 150)), points)
     frames = []
     for i in range(10):
         frame = Image.new("RGBA", (300, 169), (255, 255, 255, 0))
@@ -421,7 +503,7 @@ async def worship(users: List[UserInfo], **kwargs) -> BytesIO:
 
 
 async def eat(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = resize(users[0].img, (32, 32))
+    img = fit_size(users[0].img, (32, 32))
     frames = []
     for i in range(3):
         frame = Image.new("RGBA", (60, 67), (255, 255, 255, 0))
@@ -433,7 +515,7 @@ async def eat(users: List[UserInfo], **kwargs) -> BytesIO:
 
 
 async def bite(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     raw_frames = []
     for i in range(16):
         raw_frame = await load_image(f"bite/{i}.png")
@@ -460,14 +542,13 @@ async def police(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     bg = await load_image("police/0.png")
     frame = Image.new("RGBA", bg.size)
-    frame.paste(resize(img, (245, 245)), (224, 46))
+    frame.paste(fit_size(img, (245, 245)), (224, 46))
     frame.paste(bg, mask=bg)
     return save_jpg(frame)
 
 
 async def police1(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     bg = await load_image("police/1.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
     frame.paste(rotate(fit_size(img, (60, 75)), 16), (37, 291))
@@ -475,11 +556,8 @@ async def police1(users: List[UserInfo], **kwargs) -> BytesIO:
     return save_jpg(frame)
 
 
-async def ask(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def ask(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     img = limit_size(img, (640, 0))
     img_w, img_h = img.size
     mask_h = 150
@@ -497,7 +575,7 @@ async def ask(
     name = (args[0] if args else "") or users[0].name
     ta = "他" if users[0].gender == "male" else "她"
     if not name:
-        return "找不到名字，加上名字再试吧~"
+        raise ValueError(REQUIRE_NAME)
 
     font = await load_font(BOLD_FONT, 25)
     start_h = img_h - mask_h
@@ -529,7 +607,7 @@ async def ask(
     bg = Image.new("RGBA", (img_w + sep_w * 2, img_h + sep_h * 2), "white")
     font = await load_font(DEFAULT_FONT, 35)
     if font.getsize(name)[0] > 600:
-        return "名字太长了哦，改短点再试吧~"
+        raise ValueError(TEXT_TOO_LONG)
     await draw_text(bg, (sep_w, 10), f"让{name}告诉你吧", font=font, fill="black")
     await draw_text(
         bg, (sep_w, sep_h + img_h + 10), f"啊这，{ta}说不知道", font=font, fill="black"
@@ -543,7 +621,6 @@ async def prpr(users: List[UserInfo], **kwargs) -> BytesIO:
     bg = await load_image("prpr/0.png")
 
     async def make(img: IMG) -> IMG:
-        img = to_jpg(img)
         frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
         points = [(0, 19), (236, 0), (287, 264), (66, 351)]
         screen = perspective(fit_size(img, (330, 330)), points)
@@ -556,6 +633,7 @@ async def prpr(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def twist(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
+    img = fit_size(img, (78, 78))
     frames = []
     # fmt: off
     locs = [
@@ -566,7 +644,7 @@ async def twist(users: List[UserInfo], **kwargs) -> BytesIO:
     for i in range(5):
         frame = Image.new("RGBA", (166, 168), (255, 255, 255, 0))
         x, y, a = locs[i]
-        frame.paste(rotate(resize(img, (78, 78)), a, expand=False), (x, y))
+        frame.paste(rotate(img, a, expand=False), (x, y))
         bg = await load_image(f"twist/{i}.png")
         frame.paste(bg, mask=bg)
         frames.append(frame)
@@ -578,7 +656,6 @@ async def wallpaper(users: List[UserInfo], **kwargs) -> BytesIO:
     bg = await load_image("wallpaper/0.png")
 
     async def make(img: IMG) -> IMG:
-        img = to_jpg(img)
         frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
         frame.paste(fit_size(img, (775, 496)), (260, 580))
         frame.paste(bg, mask=bg)
@@ -591,16 +668,13 @@ async def china_flag(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     bg = await load_image("china_flag/0.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
-    frame.paste(resize(img, bg.size))
+    frame.paste(fit_size(img, bg.size))
     frame.paste(bg, mask=bg)
     return save_jpg(frame)
 
 
-async def make_friend(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def make_friend(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     img = limit_size(img, (1000, 0))
     img_w, img_h = img.size
 
@@ -613,7 +687,7 @@ async def make_friend(
 
     name = (args[0] if args else "") or users[0].name
     if not name:
-        return "找不到名字，加上名字再试吧~"
+        raise ValueError(REQUIRE_NAME)
     text_frame = Image.new("RGBA", (500, 50))
     await draw_text(text_frame, (0, -10), name, font=font, fill="#FFFFFF")
     text_frame = rotate(resize(text_frame, (250, 25)), 9)
@@ -623,7 +697,6 @@ async def make_friend(
 
 async def back_to_work(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     bg = await load_image("back_to_work/1.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
     new_img = fit_size(img, (220, 310), direction=FitSizeDir.NORTH)
@@ -634,16 +707,13 @@ async def back_to_work(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def perfect(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     frame = await load_image("perfect/0.png")
     new_img = fit_size(img, (310, 460), mode=FitSizeMode.INSIDE)
     frame.paste(new_img, (313, 64), mask=new_img)
     return save_jpg(frame)
 
 
-async def follow(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def follow(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
     img = resize(circle(img), (200, 200))
 
@@ -655,7 +725,7 @@ async def follow(
     text_follow = "关注了你"
     text_width = max(text_name_w, font.getsize(text_follow)[0])
     if text_width >= 1000:
-        return "名字太长了哦，改短点再试吧~"
+        raise ValueError(NAME_TOO_LONG)
 
     frame = Image.new("RGBA", (300 + text_width + 50, 300), (255, 255, 255, 0))
     frame.paste(img, (50, 50), mask=img)
@@ -669,12 +739,10 @@ async def follow(
     return save_jpg(frame)
 
 
-async def my_friend(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def my_friend(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
     if not args:
-        return "你朋友说啥？"
+        raise ValueError(REQUIRE_ARG)
     elif len(args) <= 1:
         name = users[0].name or "朋友"
         texts = args
@@ -686,7 +754,7 @@ async def my_friend(
     text_font = await load_font(DEFAULT_FONT, 40)
     name_w, name_h = name_font.getsize(name)
     if name_w >= 700:
-        return "名字太长了哦，改短点再试吧~"
+        raise ValueError(NAME_TOO_LONG)
 
     corner1 = await load_image("my_friend/corner1.png")
     corner2 = await load_image("my_friend/corner2.png")
@@ -737,7 +805,6 @@ async def my_friend(
 
 async def paint(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     bg = await load_image("paint/0.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
     frame.paste(rotate(fit_size(img, (117, 135)), 4), (95, 107))
@@ -747,7 +814,7 @@ async def paint(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def shock(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = resize(img, (300, 300))
+    img = fit_size(img, (300, 300))
     frames = []
     for i in range(30):
         frames.append(
@@ -760,9 +827,7 @@ async def shock(users: List[UserInfo], **kwargs) -> BytesIO:
     return save_gif(frames, 0.01)
 
 
-async def coupon(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def coupon(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
     bg = await load_image("coupon/0.png")
     new_img = rotate(resize(circle(img), (60, 60)), 22)
@@ -774,7 +839,7 @@ async def coupon(
     text += "\n（永久有效）" if len(args) <= 1 else f"\n{args[1]}"
     text_w = font.getsize_multiline(text)[0]
     if text_w > text_img.width:
-        return "文字太长了哦，改短点再试吧~"
+        raise ValueError(TEXT_TOO_LONG)
 
     await draw_text(
         text_img,
@@ -805,16 +870,15 @@ async def listen_music(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def dianzhongdian(
     users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img)
 
     if args and args[0] == "彩":
         args = args[1:]
     else:
         img = img.convert("L")
     if not args:
-        return "你想表达什么？"
+        raise ValueError(REQUIRE_ARG)
 
     img = limit_size(img, (500, 500), FitSizeMode.INSIDE)
     img_w, img_h = img.size
@@ -826,7 +890,7 @@ async def dianzhongdian(
             text, img_w - 20, img_h, fontname, max_fontsize, min_fontsize
         )
         if not fontsize:
-            return fontsize
+            raise ValueError(TEXT_TOO_LONG)
         font = await load_font(fontname, fontsize)
         text_w, text_h = font.getsize(text)
         frame = Image.new("RGB", (img_w, text_h + 5), "#000000")
@@ -835,15 +899,10 @@ async def dianzhongdian(
         return fontsize
 
     fontsize = await text_frame(args[0], 50, 10)
-    if not fontsize:
-        return "文字太长了哦，改短点再试吧~"
-
     text = args[1] if len(args) > 1 else await translate(args[0])
     if text:
         fontsize = max(int(fontsize / 2), 10)
-        fontsize = await text_frame(text, fontsize, 10)
-        if not fontsize:
-            return "文字太长了哦，改短点再试吧~"
+        await text_frame(text, fontsize, 10)
 
     frame = Image.new("RGB", (img_w, sum((f.height for f in frames)) + 10), "#000000")
     current_h = 0
@@ -855,7 +914,7 @@ async def dianzhongdian(
 
 async def funny_mirror(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = resize(img, (500, 500))
+    img = fit_size(img, (500, 500))
     frames = [img]
     coeffs = [0.01, 0.03, 0.05, 0.08, 0.12, 0.17, 0.23, 0.3, 0.4, 0.6]
     borders = [25, 52, 67, 83, 97, 108, 118, 128, 138, 148]
@@ -872,7 +931,7 @@ async def funny_mirror(users: List[UserInfo], **kwargs) -> BytesIO:
 
 
 async def love_you(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     frames = []
     locs = [(68, 65, 70, 70), (63, 59, 80, 80)]
     for i in range(2):
@@ -885,9 +944,7 @@ async def love_you(users: List[UserInfo], **kwargs) -> BytesIO:
     return save_gif(frames, 0.2)
 
 
-async def symmetric(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def symmetric(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
     img = limit_size(img, (500, 500), FitSizeMode.INSIDE)
     img_w, img_h = img.size
@@ -948,10 +1005,9 @@ async def symmetric(
     return save_jpg(frame)
 
 
-async def safe_sense(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
-    img = fit_size(to_jpg(users[0].img).convert("RGBA"), (215, 343))
+async def safe_sense(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
+    img = users[0].img
+    img = fit_size(img, (215, 343))
     frame = await load_image(f"safe_sense/0.png")
     frame.paste(img, (215, 135))
 
@@ -962,7 +1018,7 @@ async def safe_sense(
     fontname = DEFAULT_FONT
     fontsize = await fit_font_size(text, 400, 100, fontname, 70, 10)
     if not fontsize:
-        return "文字太长了哦，改短点再试吧~"
+        raise ValueError(TEXT_TOO_LONG)
     font = await load_font(fontname, fontsize)
     text_w, text_h = font.getsize_multiline(text)
     await draw_text(
@@ -976,18 +1032,16 @@ async def safe_sense(
     return save_jpg(frame)
 
 
-async def always_like(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
-    img = to_jpg(users[0].img).convert("RGBA")
+async def always_like(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
+    img = users[0].img
     name = (args[0] if args else "") or users[0].name
     if not name:
-        return "找不到名字，加上名字再试吧~"
+        raise ValueError(REQUIRE_NAME)
     text = "我永远喜欢" + name
     fontname = BOLD_FONT
     fontsize = await fit_font_size(text, 800, 100, fontname, 70, 30)
     if not fontsize:
-        return "名字太长了哦，改短点再试吧~"
+        raise ValueError(NAME_TOO_LONG)
 
     def random_color():
         return random.choice(
@@ -1021,15 +1075,15 @@ async def always_like(
         )
         name = (args[i] if len(args) > i else "") or user.name
         if not name:
-            return "找不到对应的名字，检查名字再试吧~"
+            raise ValueError("找不到对应的名字，名字数须与目标数一致")
         fontsize = await fit_font_size(name, 400, 100, fontname, 70, 30)
         if not fontsize:
-            return "名字太长了哦，改短点再试吧~"
+            raise ValueError(NAME_TOO_LONG)
         font = await load_font(fontname, fontsize)
         text_w, text_h = font.getsize(name)
         current_h -= text_h - 20
         if current_h < 10:
-            return "你喜欢的人太多啦"
+            raise ValueError("你喜欢的人太多啦")
         start_w = 400 + (430 - text_w) / 2
         await draw_text(frame, (start_w, current_h), name, font=font, fill="black")
         if len(users) > i + 1:
@@ -1042,17 +1096,15 @@ async def always_like(
     return save_jpg(frame)
 
 
-async def interview(
-    users: List[UserInfo], args: List[str] = [], **kwargs
-) -> Union[str, BytesIO]:
+async def interview(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     if len(users) >= 2:
         self_img = users[0].img
         user_img = users[1].img
     else:
         self_img = to_jpg(await load_image("interview/huaji.png"))
         user_img = users[0].img
-    self_img = resize(self_img, (124, 124))
-    user_img = resize(user_img, (124, 124))
+    self_img = fit_size(self_img, (124, 124))
+    user_img = fit_size(user_img, (124, 124))
 
     frame = Image.new("RGB", (600, 310), "white")
     microphone = await load_image("interview/microphone.png")
@@ -1064,7 +1116,7 @@ async def interview(
     fontname = DEFAULT_FONT
     fontsize = await fit_font_size(text, 550, 100, fontname, 50, 20)
     if not fontsize:
-        return "文字太长了哦，改短点再试吧~"
+        raise ValueError(TEXT_TOO_LONG)
     font = await load_font(fontname, fontsize)
     text_w, text_h = font.getsize(text)
     await draw_text(
@@ -1079,7 +1131,6 @@ async def interview(
 
 async def punch(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     img = limit_size(img, (260, 230))
     x = int((260 - img.width) / 2)
     y = int((230 - img.height) / 2)
@@ -1102,7 +1153,7 @@ async def punch(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def cyan(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = resize(img, (500, 500))
+    img = fit_size(img, (500, 500))
     color = (78, 114, 184)
     img = color_mask(img, color)
     font = await load_font(BOLD_FONT, 80)
@@ -1129,7 +1180,7 @@ async def cyan(users: List[UserInfo], **kwargs) -> BytesIO:
 
 
 async def pound(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     # fmt: off
     locs = [
         (135, 240, 138, 47), (135, 240, 138, 47), (150, 190, 105, 95), (150, 190, 105, 95),
@@ -1148,7 +1199,7 @@ async def pound(users: List[UserInfo], **kwargs) -> BytesIO:
 
 
 async def thump(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     # fmt: off
     locs = [(65, 128, 77, 72), (67, 128, 73, 72), (54, 139, 94, 61), (57, 135, 86, 65)]
     # fmt: on
@@ -1167,7 +1218,7 @@ async def need(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     bg = await load_image("need/0.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
-    frame.paste(resize(img, (115, 115)), (327, 232))
+    frame.paste(fit_size(img, (115, 115)), (327, 232))
     frame.paste(bg, mask=bg)
     return save_jpg(frame)
 
@@ -1177,14 +1228,14 @@ async def cover_face(users: List[UserInfo], **kwargs) -> BytesIO:
     bg = await load_image("cover_face/0.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
     points = [(15, 11), (448, 0), (445, 452), (0, 461)]
-    screen = perspective(resize(img, (450, 450)), points)
+    screen = perspective(fit_size(img, (450, 450)), points)
     frame.paste(screen, (120, 154))
     frame.paste(bg, mask=bg)
     return save_jpg(frame)
 
 
 async def knock(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     # fmt: off
     locs = [(60, 308, 210, 195), (60, 308, 210, 198), (45, 330, 250, 172), (58, 320, 218, 180),
             (60, 310, 215, 193), (40, 320, 250, 285), (48, 308, 226, 192), (51, 301, 223, 200)]
@@ -1202,9 +1253,13 @@ async def knock(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def garbage(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = resize(img, (79, 79))
+    img = fit_size(img, (79, 79))
     # fmt: off
-    locs = [(39, 40)] * 3 + [(39, 30)] * 2 + [(39, 32)] * 10 + [(39, 30), (39, 27), (39, 32), (37, 49), (37, 64), (37, 67), (37, 67), (39, 69), (37, 70), (37, 70)]  # type: ignore
+    locs = (
+        [] + [(39, 40)] * 3 + [(39, 30)] * 2 + [(39, 32)] * 10
+        + [(39, 30), (39, 27), (39, 32), (37, 49), (37, 64),
+           (37, 67), (37, 67), (39, 69), (37, 70), (37, 70)]
+    )
     # fmt: on
     frames = []
     for i in range(25):
@@ -1220,14 +1275,13 @@ async def whyatme(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     bg = await load_image("whyatme/0.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
-    frame.paste(resize(img, (265, 265)), (42, 13))
+    frame.paste(fit_size(img, (265, 265)), (42, 13))
     frame.paste(bg, mask=bg)
     return save_jpg(frame)
 
 
 async def decent_kiss(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = to_jpg(img).convert("RGBA")
     bg = await load_image("decent_kiss/0.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
     frame.paste(fit_size(img, (589, 340)), (0, 91))
@@ -1237,7 +1291,7 @@ async def decent_kiss(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def jiujiu(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = fit_size(to_jpg(img).convert("RGBA"), (75, 51))
+    img = fit_size(img, (75, 51))
     frames = []
     for i in range(8):
         bg = await load_image(f"jiujiu/{i}.png")
@@ -1249,7 +1303,7 @@ async def jiujiu(users: List[UserInfo], **kwargs) -> BytesIO:
 
 
 async def suck(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     # fmt: off
     locs = [(82, 100, 130, 119), (82, 94, 126, 125), (82, 120, 128, 99), (81, 164, 132, 55),
             (79, 163, 132, 55), (82, 140, 127, 79), (83, 152, 125, 67), (75, 157, 140, 62),
@@ -1267,7 +1321,7 @@ async def suck(users: List[UserInfo], **kwargs) -> BytesIO:
 
 
 async def hammer(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
+    img = square(users[0].img)
     # fmt: off
     locs = [(62, 143, 158, 113), (52, 177, 173, 105), (42, 192, 192, 92), (46, 182, 184, 100),
             (54, 169, 174, 110), (69, 128, 144, 135), (65, 130, 152, 124)]
@@ -1285,7 +1339,7 @@ async def hammer(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def tightly(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    img = fit_size(to_jpg(img).convert("RGBA"), (640, 400))
+    img = fit_size(img, (640, 400))
     # fmt: off
     locs = [(39, 169, 267, 141), (40, 167, 264, 143), (38, 174, 270, 135), (40, 167, 264, 143), (38, 174, 270, 135),
             (40, 167, 264, 143), (38, 174, 270, 135), (40, 167, 264, 143), (38, 174, 270, 135), (28, 176, 293, 134),
@@ -1301,3 +1355,39 @@ async def tightly(users: List[UserInfo], **kwargs) -> BytesIO:
         frame.paste(bg, mask=bg)
         frames.append(frame)
     return save_gif(frames, 0.08)
+
+
+async def distracted(users: List[UserInfo], **kwargs) -> BytesIO:
+    img = users[0].img
+    img = fit_size(img, (500, 500))
+    color_mask = await load_image("distracted/1.png")
+    img.paste(color_mask, (0, 0), mask=color_mask)
+    frame = await load_image("distracted/0.png")
+    img.paste(frame, (140, 320), mask=frame)
+    return save_jpg(img)
+
+
+async def anyasuki(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
+    img = users[0].img
+    # Image
+    bg = await load_image("anyasuki/0.png")
+    frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
+    frame.paste(fit_size(img, (305, 235)), (106, 72))
+    frame.paste(bg, mask=bg)
+    # Text
+    frame_w, frame_h = frame.size
+    fontname = DEFAULT_FONT
+    text = args[0] if args else "阿尼亚喜欢这个"
+    fontsize = await fit_font_size(text, frame_w - 20, 40, fontname, 40, 10)
+    if not fontsize:
+        raise ValueError(TEXT_TOO_LONG)
+    font = await load_font(fontname, fontsize)
+    text_w, text_h = font.getsize(text)
+    await draw_text(
+        frame,
+        ((frame_w - text_w) / 2, frame_h - text_h / 2 - 22),
+        text,
+        font=font,
+        fill="white",
+    )
+    return save_jpg(frame)
